@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9889 2017-04-22 14:24:50Z David $
+# $Id: __init__.py 9903 2017-04-23 13:53:33Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-04-22 22:24:50 +0800 (Sat, 22 Apr 2017) $
-# $Revision: 9889 $
+# $Date: 2017-04-23 21:53:33 +0800 (Sun, 23 Apr 2017) $
+# $Revision: 9903 $
 
 import os
 import sys
@@ -52,7 +52,6 @@ def attachSettings(settingsDict, enablePaypal=False):
     ADDING_INSTALLED_APPS = (
         'django.contrib.sites',
         'django.contrib.flatpages',
-        'compressor',
         'widget_tweaks',
     ) + tuple(get_core_apps(extraApps))
     
@@ -148,7 +147,6 @@ def attachSettings(settingsDict, enablePaypal=False):
             'STATICFILES_FINDERS': [
                 'django.contrib.staticfiles.finders.FileSystemFinder',
                 'django.contrib.staticfiles.finders.AppDirectoriesFinder',
-                'compressor.finders.CompressorFinder',
             ]
         }
         update(settingsDict, ADD_STATICFILES_FINDERS)
@@ -214,11 +212,11 @@ def attachShopURLs(settings, urlpatterns):
     @param urlpatterns urlpatterns in urls.py.
     """
 
-    from django.conf.urls import url, include, patterns
+    from django.conf.urls import url, patterns
     from oscar.app import application as shop
 
     urlpatterns += patterns('',
-        (r'^shop/', include(shop.urls)),
+        (r'^shop/', shop.urls),
     )
 
 def attachPaypalURLs(settings, urlpatterns):
@@ -231,12 +229,12 @@ def attachPaypalURLs(settings, urlpatterns):
     """
     import views
 
-    from django.conf.urls import url, include, patterns
+    from django.conf.urls import url, patterns, include
     from paypal.express.dashboard.app import application
 
     urlpatterns += patterns('',
         
-        url(r'^shop/dashboard/paypal/express/', include(application.urls)),
+        url(r'^shop/dashboard/paypal/express/', application.urls),
         url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
             views.SuccessResponseView.as_view(), name='paypal-place-order'),
         url(r'^checkout/paypal/', include('paypal.express.urls')),
